@@ -16,23 +16,20 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-/* exported init */
+/* exported LegacyTrayExtension */
 
-const { Clutter, GLib, GObject, Meta, Shell, St } = imports.gi;
+import Clutter from 'gi://Clutter';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Shell from 'gi://Shell';
+import St from 'gi://St';
 
-const ExtensionUtils = imports.misc.extensionUtils;
+import { Extension, gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const CtrlAltTab = imports.ui.ctrlAltTab;
-const Layout = imports.ui.layout;
-const Main = imports.ui.main;
-const Overview = imports.ui.overview;
-
-const Tweener = imports.tweener.tweener;
-
-const _ = ExtensionUtils.gettext;
-const Me = ExtensionUtils.getCurrentExtension();
-
-const OverviewControls = Me.imports.overviewControls;
+import * as CtrlAltTab from 'resource:///org/gnome/shell/ui/ctrlAltTab.js';
+import * as Layout from 'resource:///org/gnome/shell/ui/layout.js';
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import * as Overview from 'resource:///org/gnome/shell/ui/overview.js';
 
 const STANDARD_TRAY_ICON_IMPLEMENTATIONS = {
     'bluetooth-applet': 'bluetooth',
@@ -51,25 +48,75 @@ const STANDARD_TRAY_ICON_IMPLEMENTATIONS = {
 
 // Offset of the original position from the bottom-right corner
 const CONCEALED_WIDTH = 3;
-const REVEAL_ANIMATION_TIME = 0.2;
 const TEMP_REVEAL_TIME = 2;
 
-const BARRIER_THRESHOLD = 70;
-const BARRIER_TIMEOUT = 1000;
+function getRtlSlideDirection(direction, actor) {
+    let rtl = actor.text_direction === Clutter.TextDirection.RTL;
+    if (rtl) direction = direction === SlideDirection.LEFT ? SlideDirection.RIGHT : SlideDirection.LEFT;
+    return direction;
+}
 
-class LegacyTray {
-    constructor() {
-        this.actor = new St.Widget({
+const SlideDirection = {
+    LEFT: 0,
+    RIGHT: 1,
+};
+
+export const SlideLayout = GObject.registerClass(
+class SlideLayout extends Clutter.FixedLayout {
+    _init() {
+        this._slideX = 1;
+        this._direction = SlideDirection.LEFT;
+        super._init();
+    }
+
+    vfunc_allocate(container, box) {
+        let child = container.get_first_child();
+        let availWidth = Math.round(box.x2 - box.x1);
+        let availHeight = Math.round(box.y2 - box.y1);
+        let [, natWidth] = child.get_preferred_width(availHeight);
+        let realDirection = getRtlSlideDirection(this._direction, child);
+        let alignX = realDirection === SlideDirection.LEFT ? availWidth - natWidth : availWidth - natWidth * this._slideX;
+        let actorBox = new Clutter.ActorBox();
+        actorBox.x1 = box.x1 + alignX;
+        actorBox.x2 = actorBox.x1 + (child.x_expand ? availWidth : natWidth);
+        actorBox.y1 = box.y1;
+        actorBox.y2 = actorBox.y1 + availHeight;
+        child.allocate(actorBox);
+    }
+
+    vfunc_get_preferred_width(container, forHeight) {
+        let child = container.get_first_child();
+        let [minWidth, natWidth] = child.get_preferred_width(forHeight);
+        minWidth *= this._slideX;
+        natWidth *= this._slideX;
+        return [minWidth, natWidth];
+    }
+
+    set slide_x(value) {
+        this._slideX = value;
+        this.layout_changed();
+    }
+
+    set slideDirection(direction) {
+        this._direction = direction;
+        this.layout_changed();
+    }
+});
+
+const LegacyTray = GObject.registerClass(
+class LegacyTray extends St.Widget {
+    _init() {
+        super._init({
             name: 'LegacyTray',
             clip_to_allocation: true,
             layout_manager: new Clutter.BinLayout(),
         });
-        this.actor.add_constraint(new Layout.MonitorConstraint({
+        this.add_constraint(new Layout.MonitorConstraint({
             primary: true,
             work_area: true,
         }));
-        this._slideLayout = new OverviewControls.SlideLayout();
-        this._slideLayout.slideDirection = OverviewControls.SlideDirection.LEFT;
+        this._slideLayout = new SlideLayout();
+        this._slideLayout.slideDirection = SlideDirection.LEFT;
         this._slider = new St.Widget({
             x_expand: true,
             y_expand: true,
@@ -77,8 +124,7 @@ class LegacyTray {
             y_align: Clutter.ActorAlign.END,
             layout_manager: this._slideLayout,
         });
-        this.actor.add_child(this._slider);
-        this._slider.connect('notify::allocation', this._syncBarrier.bind(this));
+        this.add_child(this._slider);
         this._box = new St.BoxLayout({ style_class: 'legacy-tray' });
         this._slider.add_child(this._box);
         this._concealHandle = new St.Button({
@@ -103,49 +149,64 @@ class LegacyTray {
         this._concealHandle.connect('clicked', () => {
             this._revealHandle.show();
         });
-        this._horizontalBarrier = null;
-        this._pressureBarrier = new Layout.PressureBarrier(BARRIER_THRESHOLD, BARRIER_TIMEOUT, Shell.ActionMode.NORMAL);
-        this._pressureBarrier.connect('trigger', () => {
-            this._concealHandle.show();
-        });
-        Main.layoutManager.addChrome(this.actor, { affectsInputRegion: false });
+        Main.layoutManager.addChrome(this, { affectsInputRegion: false });
         Main.layoutManager.trackChrome(this._slider, { affectsInputRegion: true });
-        Main.ctrlAltTabManager.addGroup(this.actor, _('Status Icons'), 'focus-legacy-systray-symbolic', { sortGroup: CtrlAltTab.SortGroup.BOTTOM });
+        Main.ctrlAltTabManager.addGroup(this, _('Status Icons'), 'focus-legacy-systray-symbolic', { sortGroup: CtrlAltTab.SortGroup.BOTTOM });
         this._trayManager = new Shell.TrayManager();
-        this._trayManagerChangedId = [
-            this._trayManager.connect('tray-icon-added', this._onTrayIconAdded.bind(this)),
-            this._trayManager.connect('tray-icon-removed', this._onTrayIconRemoved.bind(this)),
-        ];
+        this._trayManager.connect('tray-icon-added', this._onTrayIconAdded.bind(this));
+        this._trayManager.connect('tray-icon-removed', this._onTrayIconRemoved.bind(this));
         this._trayManager.manage_screen(Main.panel);
         this._overviewChangedId = [
             Main.overview.connect('showing', () => {
-                Tweener.removeTweens(this._slider);
-                Tweener.addTween(this._slider, {
+                this._slider.remove_all_transitions();
+                this._slider.ease({
                     opacity: 0,
-                    time: Overview.ANIMATION_TIME,
-                    transition: 'easeOutQuad',
+                    duration: Overview.ANIMATION_TIME,
+                    mode: Clutter.AnimationMode.EASE_OUT_QUAD,
                 });
             }),
             Main.overview.connect('shown', this._sync.bind(this)),
             Main.overview.connect('hiding', () => {
                 this._sync();
-                Tweener.removeTweens(this._slider);
-                Tweener.addTween(this._slider, {
+                this._slider.remove_all_transitions();
+                this._slider.ease({
                     opacity: 255,
-                    time: Overview.ANIMATION_TIME,
-                    transition: 'easeOutQuad',
+                    duration: Overview.ANIMATION_TIME,
+                    mode: Clutter.AnimationMode.EASE_OUT_QUAD,
                 });
             }),
         ];
         this._monitorsChangedId = Main.layoutManager.connect('monitors-changed', this._sync.bind(this));
         this._inFullscreenChangedId = global.display.connect('in-fullscreen-changed', this._sync.bind(this));
         this._sessionModeUpdatedId = Main.sessionMode.connect('updated', this._sync.bind(this));
+        this.connect('destroy', () => this._onDestroy());
         this._sync();
     }
 
+    _onDestroy() {
+        if (this._concealHandelTimeoutId) GLib.source_remove(this._concealHandelTimeoutId);
+        if (this._sessionModeUpdatedId) Main.sessionMode.disconnect(this._sessionModeUpdatedId);
+        if (this._inFullscreenChangedId) global.display.disconnect(this._inFullscreenChangedId);
+        if (this._monitorsChangedId) Main.layoutManager.disconnect(this._monitorsChangedId);
+        this._overviewChangedId.forEach(id => {
+            Main.overview.disconnect(id);
+        });
+        this._trayManager.unmanage_screen();
+        this._trayManager = null;
+        Main.ctrlAltTabManager.removeGroup(this);
+        Main.layoutManager.untrackChrome(this._slider);
+        Main.layoutManager.removeChrome(this);
+    }
+
     _onTrayIconAdded(tm, icon) {
         let wmClass = icon.wm_class ? icon.wm_class.toLowerCase() : '';
         if (STANDARD_TRAY_ICON_IMPLEMENTATIONS[wmClass] !== undefined) return;
+        icon.set({
+            height: 24,
+            width: 24,
+            x_align: Clutter.ActorAlign.CENTER,
+            y_align: Clutter.ActorAlign.CENTER,
+        });
         let button = new St.Button({
             style_class: 'legacy-tray-icon',
             child: icon,
@@ -155,11 +216,7 @@ class LegacyTray {
         let app = Shell.WindowTracker.get_default().get_app_from_pid(icon.pid);
         if (!app) app = Shell.AppSystem.get_default().lookup_startup_wmclass(wmClass);
         if (!app) app = Shell.AppSystem.get_default().lookup_desktop_wmclass(wmClass);
-        if (app) {
-            button.accessible_name = app.get_name();
-        } else {
-            button.accessible_name = icon.title;
-        }
+        button.accessible_name = app ? app.get_name() : icon.title;
         button.connect('clicked', () => {
             icon.click(Clutter.get_current_event());
         });
@@ -182,7 +239,7 @@ class LegacyTray {
     }
 
     _onTrayIconRemoved(tm, icon) {
-        if (!this.actor.contains(icon)) return;
+        if (!this.contains(icon)) return;
         icon.get_parent().destroy();
         this._sync();
     }
@@ -192,7 +249,7 @@ class LegacyTray {
         let hasIcons = this._iconBox.get_n_children() > 0;
         let inOverview = Main.overview.visible && !Main.overview.animationInProgress;
         let inFullscreen = Main.layoutManager.primaryMonitor.inFullscreen;
-        this.actor.visible = allowed && hasIcons && !inOverview && !inFullscreen;
+        this.visible = allowed && hasIcons && !inOverview && !inFullscreen;
         if (!hasIcons) this._concealHandle.hide();
         let targetSlide;
         if (this._concealHandle.visible) {
@@ -208,81 +265,14 @@ class LegacyTray {
                 targetSlide = CONCEALED_WIDTH / boxWidth;
             }
         }
-        if (this.actor.visible) {
-            Tweener.addTween(this._slideLayout, {
-                slideX: targetSlide,
-                time: REVEAL_ANIMATION_TIME,
-                transition: 'easeOutQuad',
-            });
-        } else {
-            this._slideLayout.slide_x = targetSlide;
-            this._unsetBarrier();
-        }
-    }
-
-    _syncBarrier() {
-        let rtl = (this._slider.get_text_direction() === Clutter.TextDirection.RTL);
-        let [x, y] = this._slider.get_transformed_position();
-        let [w, h] = this._slider.get_transformed_size();
-        let x1 = Math.round(x);
-        if (rtl) x1 += Math.round(w);
-        let x2 = x1;
-        let y1 = Math.round(y);
-        let y2 = y1 + Math.round(h);
-        if (this._horizontalBarrier && this._horizontalBarrier.x1 === x1 && this._horizontalBarrier.y1 === y1 && this._horizontalBarrier.x2 === x2 && this._horizontalBarrier.y2 === y2) return;
-        this._unsetBarrier();
-        let directions = (rtl ? Meta.BarrierDirection.NEGATIVE_X : Meta.BarrierDirection.POSITIVE_X);
-        this._horizontalBarrier = new Meta.Barrier({
-            display: global.display,
-            x1: x1,
-            x2: x2,
-            y1: y1,
-            y2: y2,
-            directions: directions,
-        });
-        this._pressureBarrier.addBarrier(this._horizontalBarrier);
-    }
-
-    _unsetBarrier() {
-        if (this._horizontalBarrier === null) return;
-        this._pressureBarrier.removeBarrier(this._horizontalBarrier);
-        this._horizontalBarrier.destroy();
-        this._horizontalBarrier = null;
-    }
-
-    destroy() {
-        Tweener.removeTweens(this._slideLayout);
-        Tweener.removeTweens(this._slider);
-        if (this._concealHandelTimeoutId) GLib.source_remove(this._concealHandelTimeoutId);
-        if (this._sessionModeUpdatedId) Main.sessionMode.disconnect(this._sessionModeUpdatedId);
-        if (this._inFullscreenChangedId) global.display.disconnect(this._inFullscreenChangedId);
-        if (this._monitorsChangedId) Main.layoutManager.disconnect(this._monitorsChangedId);
-        this._overviewChangedId.forEach(id => {
-            Main.overview.disconnect(id);
-        });
-        this._trayManager.unmanage_screen();
-        this._trayManagerChangedId.forEach(id => {
-            this._trayManager.disconnect(id);
-        });
-        this._trayManager = null;
-        Main.ctrlAltTabManager.removeGroup(this.actor);
-        Main.layoutManager.untrackChrome(this._slider);
-        Main.layoutManager.removeChrome(this.actor);
-        this._unsetBarrier();
-        this._pressureBarrier.destroy();
-        this._pressureBarrier = null;
-        this.actor.destroy();
-    }
-}
-
-class Extension {
-    constructor(uuid) {
-        this._uuid = uuid;
-        ExtensionUtils.initTranslations();
+        this._slideLayout.slide_x = targetSlide;
     }
+});
 
+export default class LegacyTrayExtension extends Extension {
     _enabled() {
         this._legacyTray = new LegacyTray();
+        Main.panel.LegacyTray = this._legacyTray;
     }
 
     enable() {
@@ -297,11 +287,10 @@ class Extension {
     }
 
     disable() {
-        this._legacyTray.destroy();
-        this._legacyTray = null;
+        if (this._startupComplete) Main.layoutManager.disconnect(this._startupComplete);
+        if (this._legacyTray) {
+            this._legacyTray.destroy();
+            this._legacyTray = null;
+        }
     }
 }
-
-function init(meta) {
-    return new Extension(meta.uuid);
-}
