@@ -18,18 +18,18 @@
 
 /* exported ActivitiesButton */
 
-const { St } = imports.gi;
+import St from 'gi://St';
 
-const Main = imports.ui.main;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
 
 const ACTIVITIES_ICON = 1;
 const ACTIVITIES_NONE = 2;
 
 const KEY_SHOW_ACTIVITIES = 'show-activities';
 
-var ActivitiesButton = class {
+export class ActivitiesButton {
     constructor(settings) {
-        this._currentChild = this._label = Main.panel.statusArea.activities._label;
+        this._currentChild = this._workspaceIndicator = Main.panel.statusArea.activities.get_children()[0];
         this._icon = new St.Icon({
             style_class: 'system-status-icon',
             icon_name: 'start-here-symbolic',
@@ -44,7 +44,7 @@ var ActivitiesButton = class {
         if (showActivities === ACTIVITIES_ICON) {
             this._setChild(this._icon);
         } else {
-            this._setChild(this._label);
+            this._setChild(this._workspaceIndicator);
         }
         this._setVisibility(showActivities !== ACTIVITIES_NONE);
     }
@@ -64,8 +64,8 @@ var ActivitiesButton = class {
 
     destroy() {
         this._settings.disconnect(this._settingsChangedId);
-        this._setChild(this._label);
+        this._setChild(this._workspaceIndicator);
         this._setVisibility(true);
         this._icon.destroy();
     }
-};
+}
