@@ -18,15 +18,18 @@
 
 /* exported ApplicationsMenuButton */
 
-const { Clutter, Gio, GMenu, GObject, Shell, St } = imports.gi;
+import Clutter from 'gi://Clutter';
+import Gio from 'gi://Gio';
+import GMenu from 'gi://GMenu';
+import GObject from 'gi://GObject';
+import Shell from 'gi://Shell';
+import St from 'gi://St';
 
-const ExtensionUtils = imports.misc.extensionUtils;
+import { gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
-const PanelMenu = imports.ui.panelMenu;
-const PopupMenu = imports.ui.popupMenu;
-
-const _ = ExtensionUtils.gettext;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
+import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
 
 const APPLICATIONS_ICON = 1;
 const APPLICATIONS_TEXT = 2;
@@ -75,7 +78,7 @@ class PopupApplicationMenuItem extends PopupMenu.PopupBaseMenuItem {
     }
 });
 
-var ApplicationsMenuButton = GObject.registerClass(
+export const ApplicationsMenuButton = GObject.registerClass(
 class ApplicationsMenuButton extends PanelMenu.Button {
     _init(settings) {
         super._init(0.5, _('Applications'), false);
@@ -101,17 +104,24 @@ class ApplicationsMenuButton extends PanelMenu.Button {
             this._appSystem.connect('app-state-changed', this._reloadApplications.bind(this)),
             this._appSystem.connect('installed-changed', this._reloadApplications.bind(this)),
         ];
+        this._tree = new GMenu.Tree({ menu_basename: 'applications.menu' });
+        this._treeChangedId = this._tree.connect('changed', this._reloadApplications.bind(this));
         this._reloadApplications();
     }
 
+    _getApp(entry) {
+        let app = this._appSystem.lookup_app(entry.get_desktop_file_id());
+        if (!app) app = new Shell.App({ app_info: entry.get_app_info() });
+        return app.get_app_info().should_show() ? app : null;
+    }
+
     _getCategory(appList, appDir) {
         let iter = appDir.iter();
         let nextType;
         while ((nextType = iter.next()) !== GMenu.TreeItemType.INVALID) {
             if (nextType === GMenu.TreeItemType.ENTRY) {
-                let entry = iter.get_entry();
-                let app = this._appSystem.lookup_app(entry.get_desktop_file_id());
-                if (entry.get_app_info().should_show()) appList.push(app);
+                let app = this._getApp(iter.get_entry());
+                if (app) appList.push(app);
             } else if (nextType === GMenu.TreeItemType.DIRECTORY) {
                 if (!appDir.get_is_nodisplay()) this._getCategory(appList, iter.get_directory());
             }
@@ -125,6 +135,7 @@ class ApplicationsMenuButton extends PanelMenu.Button {
     }
 
     _onDestroy() {
+        if (this._treeChangedId) this._tree.disconnect(this._treeChangedId);
         this._appSystemChangedId.forEach(id => {
             this._appSystem.disconnect(id);
         });
@@ -134,9 +145,8 @@ class ApplicationsMenuButton extends PanelMenu.Button {
 
     _reloadApplications() {
         this.menu.removeAll();
-        let tree = new GMenu.Tree({ menu_basename: 'applications.menu' });
-        tree.load_sync();
-        let root = tree.get_root_directory();
+        this._tree.load_sync();
+        let root = this._tree.get_root_directory();
         let iter = root.iter();
         let nextType;
         while ((nextType = iter.next()) !== GMenu.TreeItemType.INVALID) {
@@ -145,9 +155,8 @@ class ApplicationsMenuButton extends PanelMenu.Button {
                 this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
                 break;
             case GMenu.TreeItemType.ENTRY:
-                let entry = iter.get_entry();
-                let app = this._appSystem.lookup_app(entry.get_desktop_file_id());
-                if (entry.get_app_info().should_show()) this.menu.addMenuItem(new PopupApplicationMenuItem(app));
+                let app = this._getApp(iter.get_entry());
+                if (app) this.menu.addMenuItem(new PopupApplicationMenuItem(app));
                 break;
             case GMenu.TreeItemType.DIRECTORY:
                 let appDir = iter.get_directory();
