@@ -18,12 +18,12 @@
 
 /* exported Dash */
 
-const Main = imports.ui.main;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
 
 const KEY_SHOW_DASH = 'show-dash';
 const KEY_SHOW_DASH_APPLICATIONS = 'show-dash-applications';
 
-var Dash = class {
+export class Dash {
     constructor(settings) {
         this._settings = settings;
         this._settingsChangedId = [
@@ -61,4 +61,4 @@ var Dash = class {
         this._setVisibilityApplications(true);
         this._setVisibility(true);
     }
-};
+}
