@@ -18,9 +18,11 @@
 
 /* exported DateMenuButton */
 
-const { Clutter, GObject, St } = imports.gi;
+import Clutter from 'gi://Clutter';
+import GObject from 'gi://GObject';
+import St from 'gi://St';
 
-const Main = imports.ui.main;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
 
 const KEY_SHOW_EVENTS_ICON = 'show-events-icon';
 
@@ -68,7 +70,7 @@ class EventsIndicator extends St.Icon {
     }
 });
 
-var DateMenuButton = class {
+export class DateMenuButton {
     constructor(settings) {
         this._indicator = new EventsIndicator(settings);
         let pos = Main.panel.statusArea.dateMenu.get_children()[0].get_n_children();
@@ -79,4 +81,4 @@ var DateMenuButton = class {
         Main.panel.statusArea.dateMenu.get_children()[0].remove_child(this._indicator);
         this._indicator.destroy();
     }
-};
+}
