@@ -16,30 +16,23 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-/* exported init */
+/* exported PanelManagerExtension */
 
-const ExtensionUtils = imports.misc.extensionUtils;
+import { Extension } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
 
-const Me = ExtensionUtils.getCurrentExtension();
-
-const { ActivitiesButton } = Me.imports.activities;
-const { ApplicationsMenuButton } = Me.imports.applications;
-const { Dash } = Me.imports.dash;
-const { DateMenuButton } = Me.imports.dateMenu;
-const { FavoritesMenuButton } = Me.imports.favorites;
-const { PlacesMenuButton } = Me.imports.places;
-const { ShowDesktopButton } = Me.imports.showDesktop;
-const { SystemMenuButton } = Me.imports.systemMenu;
-const { TrashMenuButton } = Me.imports.recycleBin;
-
-class Extension {
-    constructor(uuid) {
-        this._uuid = uuid;
-        ExtensionUtils.initTranslations();
-    }
+import { ActivitiesButton } from './activities.js';
+import { ApplicationsMenuButton } from './applications.js';
+import { Dash } from './dash.js';
+import { DateMenuButton } from './dateMenu.js';
+import { FavoritesMenuButton } from './favorites.js';
+import { PlacesMenuButton } from './places.js';
+import { ShowDesktopButton } from './showDesktop.js';
+import { SystemMenuButton } from './systemMenu.js';
+import { TrashMenuButton } from './recycleBin.js';
 
+export default class PanelManagerExtension extends Extension {
     _addToStatusArea(role, indicator, position, box) {
         return Main.panel.addToStatusArea(role, indicator, position, box);
     }
@@ -47,11 +40,11 @@ class Extension {
     _enabled(settings) {
         this._activities = new ActivitiesButton(settings);
         this._dateMenu = new DateMenuButton(settings);
-        this._systemMenu = new SystemMenuButton(this._uuid, settings);
+        this._systemMenu = new SystemMenuButton(this.uuid, settings);
         this._dash = new Dash(settings);
         this._applicationsMenu = this._addToStatusArea('applicationsMenu', new ApplicationsMenuButton(settings), 1, 'left');
         this._placesMenu = this._addToStatusArea('placesMenu', new PlacesMenuButton(settings), 2, 'left');
-        this._favoritesMenu = this._addToStatusArea('favoritesMenu', new FavoritesMenuButton(settings), 3, 'left');
+        this._favoritesMenu = this._addToStatusArea('favoritesMenu', new FavoritesMenuButton(settings, this.path), 3, 'left');
         this._showDesktop = this._addToStatusArea('showDesktop', new ShowDesktopButton(), 4, 'left');
         let pos = Main.sessionMode.panel.right.indexOf('quickSettings');
         this._trashMenu = this._addToStatusArea('trashMenu', new TrashMenuButton(), pos, 'right');
@@ -60,11 +53,11 @@ class Extension {
     enable() {
         if (Main.layoutManager._startingUp) {
             this._startupComplete = Main.layoutManager.connect('startup-complete', () => {
-                this._enabled(ExtensionUtils.getSettings());
+                this._enabled(this.getSettings());
                 Main.layoutManager.disconnect(this._startupComplete);
             });
         } else {
-            this._enabled(ExtensionUtils.getSettings());
+            this._enabled(this.getSettings());
         }
     }
 
@@ -89,7 +82,3 @@ class Extension {
         this._activities = null;
     }
 }
-
-function init(meta) {
-    return new Extension(meta.uuid);
-}
