@@ -18,15 +18,17 @@
 
 /* exported FavoritesMenuButton */
 
-const { Clutter, Gio, GObject, Shell, St } = imports.gi;
+import Clutter from 'gi://Clutter';
+import Gio from 'gi://Gio';
+import GObject from 'gi://GObject';
+import Shell from 'gi://Shell';
+import St from 'gi://St';
 
-const ExtensionUtils = imports.misc.extensionUtils;
+import { gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
-const PanelMenu = imports.ui.panelMenu;
-const PopupMenu = imports.ui.popupMenu;
-
-const _ = ExtensionUtils.gettext;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
+import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
 
 const FAVORITES_ALL = 1;
 const FAVORITES_ICON = 1;
@@ -78,15 +80,15 @@ class PopupFavoriteMenuItem extends PopupMenu.PopupBaseMenuItem {
     }
 });
 
-var FavoritesMenuButton = GObject.registerClass(
+export const FavoritesMenuButton = GObject.registerClass(
 class FavoritesMenuButton extends PanelMenu.Button {
-    _init(settings) {
+    _init(settings, path) {
         super._init(0.5, _('Favorites'), false);
         this.menu.actor.add_style_class_name('panelmanager-menu');
         this._hbox = new St.BoxLayout({ style_class: 'panel-status-indicators-box' });
         this._icon = new St.Icon({
             style_class: 'system-status-icon',
-            icon_name: 'emblem-favorite-symbolic',
+            gicon: Gio.icon_new_for_string(path + '/emblem-favorite-symbolic.svg'),
         });
         this._hbox.add_child(this._icon);
         this._label = new St.Label({
