@@ -18,15 +18,17 @@
 
 /* exported PlacesBookmarksManager PlacesRecentManager PlacesTrashManager PlacesVolumesManager */
 
-const { Gio, GLib, Gtk, Shell } = imports.gi;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import Gtk from 'gi://Gtk';
+import Shell from 'gi://Shell';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-const { EventEmitter } = imports.misc.signals;
+import { gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
-const { ShellMountOperation } = imports.ui.shellMountOperation;
+import { EventEmitter } from 'resource:///org/gnome/shell/misc/signals.js';
 
-const _ = ExtensionUtils.gettext;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import { ShellMountOperation } from 'resource:///org/gnome/shell/ui/shellMountOperation.js';
 
 class PlaceInfo {
     constructor(...params) {
@@ -75,7 +77,7 @@ class PlaceInfo {
             Gio.AppInfo.launch_default_for_uri(this.file.get_uri(), launchContext);
         } catch (e) {
             if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_MOUNTED)) {
-                let source = { get_icon: () => this.icon };
+                let source = { get_drive: () => null };
                 let op = new ShellMountOperation(source);
                 let mountArgs = [
                     Gio.MountMountFlags.NONE,
@@ -259,7 +261,7 @@ class PlaceTrashItemInfo extends PlaceInfo {
     }
 
     restore() {
-        let trash_orig_path = this.file.get_attribute_byte_string(Gio.FILE_ATTRIBUTE_TRASH_ORIG_PATH);
+        let trash_orig_path = this.file.get_attribute_as_string(Gio.FILE_ATTRIBUTE_TRASH_ORIG_PATH);
         let restoreFile = Gio.File.new_for_path(trash_orig_path);
         let restorePath = Gio.File.new_for_path(trash_orig_path.slice(0, trash_orig_path.lastIndexOf('/') + 1));
         try {
@@ -329,7 +331,7 @@ class PlacesManager extends EventEmitter {
     }
 }
 
-var PlacesBookmarksManager = class extends PlacesManager {
+export class PlacesBookmarksManager extends PlacesManager {
     _init() {
         this._bookmarksPath = GLib.build_filenamev([ GLib.get_user_config_dir(), 'gtk-3.0', 'bookmarks' ]);
         this._bookmarksFile = Gio.File.new_for_path(this._bookmarksPath);
@@ -396,9 +398,9 @@ var PlacesBookmarksManager = class extends PlacesManager {
         if (this._bookmarksTimeoutId) GLib.source_remove(this._bookmarksTimeoutId);
         super.destroy();
     }
-};
+}
 
-var PlacesRecentManager = class extends PlacesManager {
+export class PlacesRecentManager extends PlacesManager {
     _init() {
         this._recentManager = Gtk.RecentManager.get_default();
         this._recentManagerChangedId = this._recentManager.connect('changed', this._reload.bind(this));
@@ -425,9 +427,9 @@ var PlacesRecentManager = class extends PlacesManager {
         this._recentManager.disconnect(this._recentManagerChangedId);
         super.destroy();
     }
-};
+}
 
-var PlacesTrashManager = class extends PlacesManager {
+export class PlacesTrashManager extends PlacesManager {
     _init() {
         this._trash = Gio.File.new_for_uri('trash:///');
         this._trashMonitor = this._trash.monitor_directory(Gio.FileMonitorFlags.NONE, null);
@@ -471,9 +473,9 @@ var PlacesTrashManager = class extends PlacesManager {
         this._trashMonitor.disconnect(this._trashMonitorChangedId);
         super.destroy();
     }
-};
+}
 
-var PlacesVolumesManager = class extends PlacesManager {
+export class PlacesVolumesManager extends PlacesManager {
     _init() {
         super._init();
     }
@@ -534,4 +536,4 @@ var PlacesVolumesManager = class extends PlacesManager {
         this._sort('network');
         super._reload();
     }
-};
+}
