@@ -16,13 +16,15 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-/* exported init fillPreferencesWindow */
+/* exported ExtensionPanelManagerPreferences */
 
-const { Adw, Gio, GLib, GObject, Gtk } = imports.gi;
+import Adw from 'gi://Adw';
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-
-const _ = ExtensionUtils.gettext;
+import { ExtensionPreferences, gettext as _ } from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';
 
 function checkAppId(appId) {
     if (appId.indexOf('.desktop') < 0) return false;
@@ -225,9 +227,9 @@ function getPreferences(group) {
 
 const PanelManagerPreferences = GObject.registerClass(
 class PanelManagerPreferences extends Adw.PreferencesPage {
-    _init() {
+    _init(settings) {
         super._init();
-        this._settings = ExtensionUtils.getSettings();
+        this._settings = settings;
         this._createPrefGroup(getPreferences('activities'));
         this._createPrefGroup(getPreferences('applications'));
         this._createPrefGroup(getPreferences('places'));
@@ -488,10 +490,8 @@ class PanelManagerPreferences extends Adw.PreferencesPage {
     }
 });
 
-function init() {
-    ExtensionUtils.initTranslations();
-}
-
-function fillPreferencesWindow(window) {
-    window.add(new PanelManagerPreferences());
+export default class ExtensionPanelManagerPreferences extends ExtensionPreferences {
+    fillPreferencesWindow(window) {
+        window.add(new PanelManagerPreferences(this.getSettings()));
+    }
 }
