@@ -18,19 +18,19 @@
 
 /* exported TrashMenuButton */
 
-const { Clutter, Gio, GObject, St } = imports.gi;
+import Clutter from 'gi://Clutter';
+import Gio from 'gi://Gio';
+import GObject from 'gi://GObject';
+import St from 'gi://St';
 
-const ExtensionUtils = imports.misc.extensionUtils;
+import { gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
-const PanelMenu = imports.ui.panelMenu;
-const PopupMenu = imports.ui.popupMenu;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
+import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
 
-const _ = ExtensionUtils.gettext;
-const Me = ExtensionUtils.getCurrentExtension();
-
-const { PlacesTrashManager } = Me.imports.placesManager;
-const { ModalUserDialog } = Me.imports.userDialog;
+import { PlacesTrashManager } from './placesManager.js';
+import { ModalUserDialog } from './userDialog.js';
 
 const MAX_TRASH_ENTRIES = 20;
 
@@ -112,7 +112,7 @@ class PopupTrashMenuItem extends PopupMenu.PopupBaseMenuItem {
     }
 });
 
-var TrashMenuButton = GObject.registerClass(
+export const TrashMenuButton = GObject.registerClass(
 class TrashMenuButton extends PanelMenu.Button {
     _init() {
         super._init(0.5, _('Trash'), false);
