@@ -18,16 +18,16 @@
 
 /* exported ShowDesktopButton */
 
-const { GObject, Shell, St } = imports.gi;
+import GObject from 'gi://GObject';
+import Shell from 'gi://Shell';
+import St from 'gi://St';
 
-const ExtensionUtils = imports.misc.extensionUtils;
+import { gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
-const PanelMenu = imports.ui.panelMenu;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
 
-const _ = ExtensionUtils.gettext;
-
-var ShowDesktopButton = GObject.registerClass(
+export const ShowDesktopButton = GObject.registerClass(
 class ShowDesktopButton extends PanelMenu.Button {
     _init() {
         super._init(0.0, _('Show Desktop'), true);
