@@ -18,17 +18,20 @@
 
 /* exported SystemMenuButton */
 
-const { Gio, GLib, GObject, Shell, St } = imports.gi;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Shell from 'gi://Shell';
+import St from 'gi://St';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-const LoginManager = imports.misc.loginManager;
-const Util = imports.misc.util;
+import { Extension, gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
-const PopupMenu = imports.ui.popupMenu;
-const QuickSettings = imports.ui.quickSettings;
+import * as LoginManager from 'resource:///org/gnome/shell/misc/loginManager.js';
+import * as Util from 'resource:///org/gnome/shell/misc/util.js';
 
-const _ = ExtensionUtils.gettext;
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
+import * as QuickSettings from 'resource:///org/gnome/shell/ui/quickSettings.js';
 
 const BASIC_SETTINGS = [
     'ca.desrt.dconf-editor.desktop',        // dconf-editor
@@ -206,7 +209,7 @@ class SystemBasicSettingsIndicator extends QuickSettings.SystemIndicator {
     _init(settings) {
         super._init();
         this._basicSettings = new QuickSettings.QuickMenuToggle({
-            label: _('Basic Settings'),
+            title: _('Basic Settings'),
             iconName: 'preferences-system-symbolic',
         });
         this._basicSettings.menu.setHeader('preferences-system-symbolic', _('Basic Settings'));
@@ -251,7 +254,7 @@ class SystemBasicSettingsIndicator extends QuickSettings.SystemIndicator {
     }
 });
 
-var SystemMenuButton = class {
+export class SystemMenuButton {
     constructor(uuid, settings) {
         this._currentChild = Main.panel.statusArea.quickSettings._indicators;
         this._icon = new St.Icon({
@@ -264,7 +267,7 @@ var SystemMenuButton = class {
         this._system = new SystemIndicator(uuid, settings);
         this._basicSettings = new SystemBasicSettingsIndicator(settings);
         Main.panel.statusArea.quickSettings._indicators.add_child(this._basicSettings);
-        Main.panel.statusArea.quickSettings._addItems(this._basicSettings.quickSettingsItems, N_QUICK_SETTINGS_COLUMNS);
+        this._basicSettings.quickSettingsItems.forEach(item => Main.panel.statusArea.quickSettings.menu.addItem(item, N_QUICK_SETTINGS_COLUMNS));
     }
 
     _onChangedShowSystemMenu() {
@@ -291,4 +294,4 @@ var SystemMenuButton = class {
         this._setChild(Main.panel.statusArea.quickSettings._indicators);
         this._icon.destroy();
     }
-};
+}
