@@ -18,14 +18,13 @@
 
 /* exported ModalUserDialog */
 
-const { Clutter, GObject } = imports.gi;
+import Clutter from 'gi://Clutter';
+import GObject from 'gi://GObject';
 
-const ExtensionUtils = imports.misc.extensionUtils;
+import { Extension, gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const { MessageDialogContent } = imports.ui.dialog;
-const { ModalDialog } = imports.ui.modalDialog;
-
-const _ = ExtensionUtils.gettext;
+import { MessageDialogContent } from 'resource:///org/gnome/shell/ui/dialog.js';
+import { ModalDialog } from 'resource:///org/gnome/shell/ui/modalDialog.js';
 
 function getDialogContent(content) {
     let dialogContent = null;
@@ -115,7 +114,7 @@ function getDialogContent(content) {
     return dialogContent;
 }
 
-var ModalUserDialog = GObject.registerClass({
+export const ModalUserDialog = GObject.registerClass({
     Signals:{
         'eject': {},
         'empty': {},
