@@ -16,21 +16,21 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-/* exported init */
+/* exported TemperatureExtension */
 
-const { Clutter, GObject, St } = imports.gi;
+import Clutter from 'gi://Clutter';
+import GObject from 'gi://GObject';
+import St from 'gi://St';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-const Util = imports.misc.util;
+import { Extension, gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Main = imports.ui.main;
-const PanelMenu = imports.ui.panelMenu;
-const PopupMenu = imports.ui.popupMenu;
+import * as Util from 'resource:///org/gnome/shell/misc/util.js';
 
-const _ = ExtensionUtils.gettext;
-const Me = ExtensionUtils.getCurrentExtension();
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
+import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
+import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
 
-const { SensorManager } = Me.imports.sensors;
+import { SensorManager } from './sensors.js';
 
 const KEY_REFRESH_INTERVAL = 'refresh-interval';
 const KEY_SHOW_FAHRENHEIT = 'show-fahrenheit';
@@ -345,14 +345,9 @@ class TemperatureMenuButton extends PanelMenu.Button {
     }
 });
 
-class Extension {
-    constructor(uuid) {
-        this._uuid = uuid;
-        ExtensionUtils.initTranslations();
-    }
-
-    _enabled(settings) {
-        this._temperatureMenu = new TemperatureMenuButton(this._uuid, settings);
+export default class TemperatureExtension extends Extension {
+    _enabled() {
+        this._temperatureMenu = new TemperatureMenuButton(this.uuid, this.getSettings());
         let pos = Main.sessionMode.panel.left.indexOf('dateMenu');
         Main.panel.addToStatusArea('temperatureMenu', this._temperatureMenu, pos, 'center');
     }
@@ -360,11 +355,11 @@ class Extension {
     enable() {
         if (Main.layoutManager._startingUp) {
             this._startupComplete = Main.layoutManager.connect('startup-complete', () => {
-                this._enabled(ExtensionUtils.getSettings());
+                this._enabled();
                 Main.layoutManager.disconnect(this._startupComplete);
             });
         } else {
-            this._enabled(ExtensionUtils.getSettings());
+            this._enabled();
         }
     }
 
@@ -373,7 +368,3 @@ class Extension {
         this._temperatureMenu = null;
     }
 }
-
-function init(meta) {
-    return new Extension(meta.uuid);
-}
