@@ -16,13 +16,14 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-/* exported init fillPreferencesWindow */
+/* exported ExtensionTemperaturePreferences */
 
-const { Adw, Gio, GObject, Gtk } = imports.gi;
+import Adw from 'gi://Adw';
+import Gio from 'gi://Gio';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-
-const _ = ExtensionUtils.gettext;
+import { ExtensionPreferences, gettext as _ } from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';
 
 function getPreferences(group) {
     let prefGroup = null;
@@ -67,9 +68,9 @@ function getPreferences(group) {
 
 const TemperaturePreferences = GObject.registerClass(
 class TemperaturePreferences extends Adw.PreferencesPage {
-    _init() {
+    _init(settings) {
         super._init();
-        this._settings = ExtensionUtils.getSettings();
+        this._settings = settings;
         this._createPrefGroup(getPreferences('fahrenheit'));
         this._createPrefGroup(getPreferences('refresh'));
     }
@@ -128,10 +129,8 @@ class TemperaturePreferences extends Adw.PreferencesPage {
     }
 });
 
-function init() {
-    ExtensionUtils.initTranslations();
-}
-
-function fillPreferencesWindow(window) {
-    window.add(new TemperaturePreferences());
+export default class ExtensionTemperaturePreferences extends ExtensionPreferences {
+    fillPreferencesWindow(window) {
+        window.add(new TemperaturePreferences(this.getSettings()));
+    }
 }
