@@ -18,12 +18,13 @@
 
 /* exported SensorManager */
 
-const { Gio, GLib, Shell } = imports.gi;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import Shell from 'gi://Shell';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-const { EventEmitter } = imports.misc.signals;
+import { gettext as _ } from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const _ = ExtensionUtils.gettext;
+import { EventEmitter } from 'resource:///org/gnome/shell/misc/signals.js';
 
 const DEFAULT_REFRESH_INTERVAL = 600;
 
@@ -323,7 +324,7 @@ class SensorVGAInfo extends SensorInfo {
     }
 }
 
-var SensorManager = class extends EventEmitter {
+export class SensorManager extends EventEmitter {
     constructor() {
         super();
         this.sensor = {
@@ -409,4 +410,4 @@ var SensorManager = class extends EventEmitter {
         }
         return result;
     }
-};
+}
